<?php
/**
 * General Configuration template class
 *
 * @package MultiPOS - Point of Sale for WooCommerce
 * @version 1.0.0
 */

namespace DDWCMultiPOS\Templates\Admin\Configuration;

use DDWCMultiPOS\Helper\File\DDWCPOS_File_Create_Helper;

defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'DDWCPOS_General_Configuration_Template' ) ) {
	/**
	 * General Configuration template class
	 */
	class DDWCPOS_General_Configuration_Template {
		/**
		 * Construct
		 */
		public function __construct( $ddwcpos_configuration ) {
			if ( ! empty( $_GET[ 'settings-updated' ] ) && 'true' === $_GET[ 'settings-updated' ] ) {
				flush_rewrite_rules();

				$file_create_helper = new DDWCPOS_File_Create_Helper( $ddwcpos_configuration );
				$file_create_helper->ddwcpos_generate_new_manifest_file();
				$file_create_helper->ddwcpos_write_service_worker();
			}

			$license_activated = get_option( '_ddwcpos_license_activated' );
			$purchase_code     = get_option( '_ddwcpos_purchase_code' );
			$purchase_email    = get_option( '_ddwcpos_purchase_email' );

			if ( ! empty( $license_activated ) ) {
				$args = [
					'purchase_code' => $purchase_code,
					'user_agent'    => site_url(),
				];

				$response = wp_remote_post( 'https://devdiggers.com/wp-json/ddelv/v1/check-license', [
					'body' => json_encode( $args )
				] );

				$response = json_decode( wp_remote_retrieve_body( $response ) );

				if ( ! empty( $response ) && $response->success && ( 'deactivated' === $response->status || 'deleted' === $response->status ) ) {
					delete_option( '_ddwcpos_license_activated' );
					$license_activated = '';
				}
			}

			?>
			<div class="wrap">
				<hr class="wp-header-end" />
				<?php settings_errors(); ?>
				<div class="ddwcpos-configuration-container ddwcpos-padding-top-bottom-0">
					<form action="options.php" method="POST">
						<?php settings_fields( 'ddwcpos-general-configuration-fields' ); ?>
						<h2><?php esc_html_e( 'General Configuration', 'ddwc-multipos' ); ?></h2>
						<table class="form-table">
							<tbody>
								<tr valign='top'>
									<th scope='row' class='titledesc'>
										<label for='ddwcpos-purchase-code'><?php esc_html_e( 'Activate License', 'ddwc-multipos' ); ?></label>
									</th>
									<td class='forminp forminp-text'>
										<?php echo wc_help_tip( esc_html__( 'Enter your purchase code to activate your purchased license. You\'ll not able to use the plugin until you activate the license.', 'ddwc-multipos' ), true ); ?>

										<input type="text" name="_ddwcpos_purchase_code" class="regular-text <?php echo esc_attr( ! empty( $license_activated ) ? 'ddwcpos-hide' : '' ); ?>" id="ddwcpos-purchase-code" value="<?php echo esc_attr( $purchase_code ); ?>" placeholder="<?php esc_attr_e( 'Enter Purchase Code', 'ddwc-multipos' ); ?>" />

										<input type="email" name="_ddwcpos_purchase_email" class="regular-text <?php echo esc_attr( ! empty( $license_activated ) ? 'ddwcpos-hide' : '' ); ?>" id="ddwcpos-purchase-email" value="<?php echo esc_attr( $purchase_email ); ?>" placeholder="<?php esc_attr_e( 'Enter Purchase email', 'ddwc-multipos' ); ?>" />

										<button class="button button-primary ddwcpos-verify-license <?php echo esc_attr( ! empty( $license_activated ) ? 'ddwcpos-hide' : '' ); ?>" data-action="activate" data-fetching="<?php esc_attr_e( 'Activating...', 'ddwc-multipos' ); ?>"><?php esc_html_e( 'Activate', 'ddwc-multipos' ); ?></button>

										<button class="button button-primary ddwcpos-verify-license <?php echo esc_attr( empty( $license_activated ) ? 'ddwcpos-hide' : '' ); ?>" data-action="deactivate" data-fetching="<?php esc_attr_e( 'Deactivating...', 'ddwc-multipos' ); ?>"><?php esc_html_e( 'Deactivate', 'ddwc-multipos' ); ?></button>

										<p class="description ddwcpos-margin-left-20"><a href="<?php echo esc_url( '//devdiggers.com/license-activation/' ); ?>" target="__blank"><?php esc_html_e( 'How to find your purchase code?', 'ddwc-multipos' ); ?></a></p>

										<div class="notice ddwcpos-hide">
											<p class="ddwcpos-license-status"></p>
										</div>
									</td>
								</tr>
								<?php
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Enable MultiPOS - Point of Sale for WooCommerce', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable the module functionalities for the users.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'This allows the module functionality to be used on the frontend.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-enabled',
									'value'          => $ddwcpos_configuration[ 'enabled' ],
								] );
								ddwcpos_form_field( [
									'type'        => 'select',
									'label'       => esc_html__( 'Inventory Type', 'ddwc-multipos' ),
									'help_tip'    => esc_html__( 'In centralized stock, WooCommerce stock will be synced at POS end and in custom/manual stock, any stock can be given to all the products that does not affect the WooCommerce stock which will be used at the POS end.', 'ddwc-multipos' ),
									'description' => esc_html__( 'Choose the default or global inventory type for the Outlet.', 'ddwc-multipos' ),
									'options'     => [
										'centralized' => esc_html__( 'Centralized/WooCommerce Stock', 'ddwc-multipos' ),
										'custom'      => esc_html__( 'Custom/Manual Stock', 'ddwc-multipos' ),
									],
									'id'          => 'ddwcpos-inventory-type',
									'value'       => $ddwcpos_configuration[ 'inventory_type' ],
									'input_class' => [ 'ddwcpos-select2' ],
								] );
								ddwcpos_form_field( [
									'type'        => 'select',
									'label'       => esc_html__( 'Order Status', 'ddwc-multipos' ),
									'help_tip'    => esc_html__( 'Both default and custom order statuses can be used.', 'ddwc-multipos' ),
									'description' => esc_html__( 'Choose the status for the orders generated at the POS end.', 'ddwc-multipos' ),
									'options'     => wc_get_order_statuses(),
									'id'          => 'ddwcpos-order-status',
									'value'       => $ddwcpos_configuration[ 'order_status' ],
									'input_class' => [ 'ddwcpos-select2' ],
								] );
								ddwcpos_form_field( [
									'type'        => 'select',
									'label'       => esc_html__( 'Default Product Barcode', 'ddwc-multipos' ),
									'help_tip'    => esc_html__( 'Select the default barcode by which barcodes get generated automatically for the products and can be scanned at the POS end.', 'ddwc-multipos' ),
									'description' => esc_html__( 'Choose the default barcode type for the product.', 'ddwc-multipos' ),
									'options'     => [
										'id'  => esc_html__( 'Product ID', 'ddwc-multipos' ),
										'sku' => esc_html__( 'Product SKU', 'ddwc-multipos' ),
									],
									'id'          => 'ddwcpos-default-barcode',
									'value'       => $ddwcpos_configuration[ 'default_barcode' ],
									'input_class' => [ 'ddwcpos-select2' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Enable Order Mails', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable order mails at the POS end, both admin & customer mails can be enabled/disabled from here.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Choose to allow order mails.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-order-mails-enabled',
									'value'          => $ddwcpos_configuration[ 'order_mails_enabled' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Enable Split/Multiple Payment Methods', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable the split/multiple payment methods for paying at the POS end.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Choose to allow split or multiple payment methods.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-multiple-payments-enabled',
									'value'          => $ddwcpos_configuration[ 'multiple_payments_enabled' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Enable Order Note', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable to enter order note at the POS end.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Choose to allow to add notes on the order.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-order-note-enabled',
									'value'          => $ddwcpos_configuration[ 'order_note_enabled' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Enable Offline Orders for Online Mode (Fast Orders)', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable offline orders for online mode then automatic sync to speed up the order process at the POS end.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Choose to process orders as offline even on active internet connection.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-offline-orders-enabled',
									'value'          => $ddwcpos_configuration[ 'offline_orders_enabled' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Enable Adding Custom Product', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable adding custom product at the POS end.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Choose to allow adding custom products for that specific order.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-custom-product-enabled',
									'value'          => $ddwcpos_configuration[ 'custom_product_enabled' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Enable Open Cash Drawer Popup', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable the open cash drawer popup at POS end.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Choose to allow displaying open cash drawer popup on loading of the POS to enter any existing cash amount of the drawer.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-opencash-drawer-enabled',
									'value'          => $ddwcpos_configuration[ 'opencash_drawer_enabled' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Enable Unit/Weight Based Pricing', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable unit or weight based pricing so prices of the products containing weight can be modified according to the entered weight at the POS end.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Choose to allow weight based pricing and product price will get calculated automatically as per the entered weight.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-unit-price-enabled',
									'value'          => $ddwcpos_configuration[ 'unit_price_enabled' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Automatic Send Orders to Kitchen When Put to Hold', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable automatic sending of orders to the kitchen screen for restaurant mode outlets.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Choose to send orders to the kitchen screen automatically when put to hold.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-automatic-send-kitchen-order-enabled',
									'value'          => $ddwcpos_configuration[ 'automatic_send_kitchen_order_enabled' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Send Placed Orders to Kitchen Checked by Default', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable the checkbox for sending placed orders to kitchen screen for restaurant mode outlets.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Choose to auto-checked the send placed orders to the kitchen screen checkbox.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-order-send-kitchen-checked-enabled',
									'value'          => $ddwcpos_configuration[ 'order_send_kitchen_checked_enabled' ],
								] );
								?>
								<tr valign="top">
									<th scope="row" class="titledesc">
										<label for="ddwcpos-logo"><?php esc_html_e( 'Logo', 'ddwc-multipos' ); ?></label>
									</th>
									<td>
										<img src="<?php echo esc_url( ! empty( $ddwcpos_configuration[ 'logo' ] ) ? wp_get_attachment_url( $ddwcpos_configuration[ 'logo' ] ) : DDWCPOS_PLUGIN_URL . 'assets/images/logo.png' ); ?>" alt='icon' class="image-url" width="80">
										<input type="hidden" id="ddwcpos-logo" name="_ddwcpos_logo" value="<?php echo esc_attr( $ddwcpos_configuration[ 'logo' ] ); ?>" />
										<br />
										<button data-id="ddwcpos-logo" class="button-primary ddwcpos-icon-upload"><?php esc_html_e( 'Upload Icon', 'ddwc-multipos' ); ?></button>
										<?php echo wc_help_tip( esc_html__( 'Upload the logo of the outlet.', 'ddwc-multipos' ), true ); ?>
									</td>
								</tr>
								<tr valign='top'>
									<th scope='row' class='titledesc'>
										<label for='ddwcpos-default-customer'><?php esc_html_e( 'Select Default/Guest Customer', 'ddwc-multipos' ); ?></label>
									</th>
									<td class='forminp forminp-text'>
										<?php echo wc_help_tip( esc_html__( 'This customer is used for the guest orders at POS end.', 'ddwc-multipos' ), true ); ?>
										<select id="ddwcpos-default-customer" name="_ddwcpos_default_customer" class="ddwcpos-users regular-text" data-placeholder="<?php esc_attr_e( 'Select Customer', 'ddwc-multipos' ); ?>">
											<?php
											if ( ! empty( $ddwcpos_configuration[ 'default_customer' ] ) ) {
												$customer_id           = $ddwcpos_configuration[ 'default_customer' ];
												$customer_data         = get_userdata( $customer_id );
												$customer_option_value = "(#{$customer_id}) {$customer_data->user_login} <{$customer_data->user_email}>";
												?>
												<option value="<?php echo esc_attr( $customer_id ); ?>"><?php echo esc_html( $customer_option_value ); ?></option>
												<?php
											}
											?>
										</select>
									</td>
								</tr>
								<?php
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Load only Guest/Default Customer', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable the checkbox to load only guest or default customer.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Choose to load only guest customer if it is selected.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-load-only-guest-customer-enabled',
									'value'          => $ddwcpos_configuration[ 'load_only_guest_customer_enabled' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'number',
									'label'          => esc_html__( 'Load Orders Only Day(s) Old', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enter the number of days to load orders only for this period.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Enter the period to load specific orders.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-load-orders-only-days-old',
									'value'          => $ddwcpos_configuration[ 'load_orders_only_days_old' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'text',
									'label'          => esc_html__( 'Endpoint', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enter the endpoint which will be used after your site URL to access the POS.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'This endpoint is used to access the POS.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-endpoint',
									'value'          => $ddwcpos_configuration[ 'endpoint' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'text',
									'label'          => esc_html__( 'Kitchen Endpoint', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enter the endpoint which will be used after your site URL to access the Kitchen view for the POS. This view can only be used for the restaurant mode outlets.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'This endpoint is used to access the kitchen view.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-kitchen-endpoint',
									'value'          => $ddwcpos_configuration[ 'kitchen_endpoint' ],
								] );
								?>
							</tbody>
						</table>
						<p class="description">
							<i>
								<?php
								echo sprintf( esc_html__( 'If you really like our plugin, please leave us a %s rating, we\'ll really appreciate it.', 'ddwc-multipos' ), '<a href="//codecanyon.net/downloads" target="_blank" title="' . esc_attr__( 'Review', 'ddwc-multipos' ) . '" aria-label="' . esc_attr__( 'Review', 'ddwc-multipos' ) . '"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 192 32" height="10"><path d="M16 26.534L6.111 32 8 20.422l-8-8.2 11.056-1.688L16 0l4.944 10.534L32 12.223l-8 8.2L25.889 32zm40 0L46.111 32 48 20.422l-8-8.2 11.056-1.688L56 0l4.944 10.534L72 12.223l-8 8.2L65.889 32zm40 0L86.111 32 88 20.422l-8-8.2 11.056-1.688L96 0l4.944 10.534L112 12.223l-8 8.2L105.889 32zm40 0L126.111 32 128 20.422l-8-8.2 11.056-1.688L136 0l4.944 10.534L152 12.223l-8 8.2L145.889 32zm40 0L166.111 32 168 20.422l-8-8.2 11.056-1.688L176 0l4.944 10.534L192 12.223l-8 8.2L185.889 32z" fill="#F5A623" fill-rule="evenodd"/></svg></a>' )
								?>
							</i>
						</p>
						<?php submit_button( esc_html__( 'Save Changes', 'ddwc-multipos' ) ); ?>
					</form>
				</div>
			</div>
			<?php
		}
	}
}
